@@ -51,12 +51,6 @@ def enter_and_leave_function(func: Callable) -> Callable:
         func_def_file = inspect.getsourcefile(func) or "unknown_file"
         func_def_file = func_def_file.split("/")[-1]
         func_def_line = inspect.getsourcelines(func)[1] if func_def_file != "unknown_file" else "unknown_line"
-        log.info(
-            f"[{func_def_file}: {func_def_line}]"
-            f"[{func.__name__}()]"
-            f"| args={args}, kwargs={kwargs}"
-        )
-
         try:
             result = func(*args, **kwargs)
             if isinstance(result, ExecResult):
@@ -142,7 +136,6 @@ class SSHClient(object):
 
     @enter_and_leave_function
     def __connect(self):
-        log.info(f" {self.__ip}:{self.__port} | begin to create ssh connect.")
         try:
             self.__ssh = paramiko.SSHClient()
             self.__ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
@@ -155,7 +148,6 @@ class SSHClient(object):
                 allow_agent=False,
                 timeout=self.__connect_timeout
             )
-            log.info(f"{self.__ip}:{self.__port} | ssh connect successfully.")
             return True
         except socket.timeout as e:
             log.warning(f"{self.__ip}:{self.__port} | failed to ssh connect. err msg is {str(e)}")
